#ifndef NT2_INCLUDE_FUNCTIONS_AVERAGE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_AVERAGE_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/average.hpp>

#endif
